==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/QuickStartsFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class QuickStartsFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.QuickStartsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.QuickStartsFluent<A>{
  public QuickStartsFluentImpl() {
  }
  public QuickStartsFluentImpl(io.fabric8.openshift.api.model.operator.v1.QuickStarts instance) {
    this.withDisabled(instance.getDisabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> disabled = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(java.util.Collection<java.lang.String> items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabled() {
    return this.disabled;
  }
  public java.lang.String getDisabled(java.lang.Integer index) {
    return this.disabled.get(index);
  }
  public java.lang.String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public java.lang.String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public java.lang.String getMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(java.util.List<java.lang.String> disabled) {
    if (disabled != null) {this.disabled = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear();}
    if (disabled != null) {for (java.lang.String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addNewDisabled(java.lang.String arg0) {
    return (A)addToDisabled(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QuickStartsFluentImpl that = (QuickStartsFluentImpl) o;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.12.2-sources.jar: io/fabric8/openshift/api/model/operator/v1/QuickStartsFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class QuickStartsFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.QuickStartsFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.QuickStartsFluent<A>{
  public QuickStartsFluentImpl() {
  }
  public QuickStartsFluentImpl(io.fabric8.openshift.api.model.operator.v1.QuickStarts instance) {
    this.withDisabled(instance.getDisabled()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> disabled = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.add(index, item);
    return (A)this;
  }
  public A setToDisabled(java.lang.Integer index,java.lang.String item) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    this.disabled.set(index, item); return (A)this;
  }
  public A addToDisabled(java.lang.String... items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A addAllToDisabled(java.util.Collection<java.lang.String> items) {
    if (this.disabled == null) {this.disabled = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.disabled.add(item);} return (A)this;
  }
  public A removeFromDisabled(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public A removeAllFromDisabled(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.disabled!= null){ this.disabled.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getDisabled() {
    return this.disabled;
  }
  public java.lang.String getDisabled(java.lang.Integer index) {
    return this.disabled.get(index);
  }
  public java.lang.String getFirstDisabled() {
    return this.disabled.get(0);
  }
  public java.lang.String getLastDisabled() {
    return this.disabled.get(disabled.size() - 1);
  }
  public java.lang.String getMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingDisabled(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: disabled) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withDisabled(java.util.List<java.lang.String> disabled) {
    if (disabled != null) {this.disabled = new java.util.ArrayList(); for (java.lang.String item : disabled){this.addToDisabled(item);}} else { this.disabled = null;} return (A) this;
  }
  public A withDisabled(java.lang.String... disabled) {
    if (this.disabled != null) {this.disabled.clear();}
    if (disabled != null) {for (java.lang.String item :disabled){ this.addToDisabled(item);}} return (A) this;
  }
  public java.lang.Boolean hasDisabled() {
    return disabled != null && !disabled.isEmpty();
  }
  public A addNewDisabled(java.lang.String arg0) {
    return (A)addToDisabled(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    QuickStartsFluentImpl that = (QuickStartsFluentImpl) o;
    if (disabled != null ? !disabled.equals(that.disabled) :that.disabled != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(disabled,  additionalProperties,  super.hashCode());
  }
  
}
